@@ -1,15 +1,15 @@
 import logging
-from typing import Any, Sequence, Union
-from dictIO import Parser, Formatter
+from typing import Any, List, Sequence, Union
 
+from dictIO import Formatter, Parser
 
-__ALL__ = ['ScalarVariable', 'get_fmi_data_type']
+__ALL__ = ["ScalarVariable", "get_fmi_data_type"]
 
 logger = logging.getLogger(__name__)
 
 
-class ScalarVariable():
-    """fmi 2.0 ScalarVariable
+class ScalarVariable:
+    """fmi 2.0 ScalarVariable.
 
     See https://github.com/modelica/fmi-standard/blob/v2.0.x/schema/fmi2ScalarVariable.xsd
     """
@@ -30,7 +30,7 @@ class ScalarVariable():
         # Attributes
         self.name: str
         self._data_type: Union[str, None] = None
-        self._causality: str = 'local'
+        self._causality: str = "local"
         self._variability: Union[str, None] = None
         self._start: Union[int, float, bool, str, None] = None
         self.value_reference: int = 0
@@ -61,11 +61,11 @@ class ScalarVariable():
     @data_type.setter
     def data_type(self, type: str):
         valid_types: list[str] = [
-            'Real',
-            'Integer',
-            'Boolean',
-            'String',
-            'Enumeration',
+            "Real",
+            "Integer",
+            "Boolean",
+            "String",
+            "Enumeration",
         ]
         if type not in valid_types:
             logger.error(f"variable {self.name}: value for data_type '{type}' is invalid.")
@@ -80,13 +80,13 @@ class ScalarVariable():
     @causality.setter
     def causality(self, value: str):
         valid_values: list[str] = [
-            'parameter',
-            'calculatedParameter',
-            'input',
-            'output',
-            'local',
-            'independent',
-            'structuralParameter',
+            "parameter",
+            "calculatedParameter",
+            "input",
+            "output",
+            "local",
+            "independent",
+            "structuralParameter",
         ]
         if value not in valid_values:
             logger.error(f"variable {self.name}: causality value '{value}' is invalid.")
@@ -101,11 +101,11 @@ class ScalarVariable():
     @variability.setter
     def variability(self, value: str):
         valid_values: list[str] = [
-            'constant',
-            'fixed',
-            'tunable',
-            'discrete',
-            'continuous',
+            "constant",
+            "fixed",
+            "tunable",
+            "discrete",
+            "continuous",
         ]
         if value not in valid_values:
             logger.error(f"variable {self.name}: value for variability '{value}' is invalid.")
@@ -120,9 +120,7 @@ class ScalarVariable():
     @start.setter
     def start(self, value: Union[int, float, bool, str, None]):
         if value is None:
-            logger.error(
-                f"variable {self.name}: start shall be set to 'None', but 'None' is invalid for start."
-            )
+            logger.error(f"variable {self.name}: start shall be set to 'None', but 'None' is invalid for start.")
             return
         if self.data_type:
             # make sure the data type of the new value does either match or gets casted to the data_type defined for the variable
@@ -149,7 +147,7 @@ class ScalarVariable():
 
 
 def get_fmi_data_type(arg: Any) -> str:
-    """Returns the fmi 2.0 data type of the passed in argument
+    r"""Returns the fmi 2.0 data type of the passed in argument.
 
     See https://github.com/modelica/fmi-standard/blob/v2.0.x/schema/fmi2Type.xsd
 
@@ -166,24 +164,27 @@ def get_fmi_data_type(arg: Any) -> str:
     """
 
     if isinstance(arg, int):
-        return 'Integer'
+        return "Integer"
     elif isinstance(arg, float):
-        return 'Real'
+        return "Real"
     elif isinstance(arg, bool):
-        return 'Boolean'
-    elif isinstance(arg, Sequence):
-        return 'Enumeration'
+        return "Boolean"
+    # not regarding the content, sequence is always returned if not int or float, e.g. string.
+    # requires a solution, if xs:enumeration is required.
+    # elif isinstance(arg, Sequence):
+    #    return 'Enumeration'
     else:
-        return 'String'
+        return "String"
 
 
-def _cast_to_fmi_data_type(arg: Union[int, float, bool, str, Sequence],
-                           fmi_data_type: str) -> Union[int, float, bool, str, list, None]:
-    """Casts the passed in argument to a Python data type that matches the requested fmi data type
+def _cast_to_fmi_data_type(
+    arg: Union[int, float, bool, str, Sequence[Any]], fmi_data_type: str
+) -> Union[int, float, bool, str, List[Any], None]:
+    r"""Casts the passed in argument to a Python data type that matches the requested fmi data type.
 
     Parameters
     ----------
-    arg : Union[int, float, bool, str, Sequence]
+    arg : Union[int, float, bool, str, Sequence[Any]]
         The argument to be casted
     fmi_data_type : str
         The fmi data type the argument shall be casted to.\n
@@ -191,10 +192,10 @@ def _cast_to_fmi_data_type(arg: Union[int, float, bool, str, Sequence],
 
     Returns
     -------
-    Union[int, float, bool, str, list, None]
+    Union[int, float, bool, str, List[Any], None]
         The casted value (in a Python data type that matches the requested fmi data type)
     """
-    if fmi_data_type in {'Integer', 'Real', 'Boolean'}:
+    if fmi_data_type in {"Integer", "Real", "Boolean"}:
         if isinstance(arg, Sequence):
             logger.warning(
                 f"_cast_to_fmi_data_type(): argument {arg} of type List/Tuple/Sequence cannot be casted to fmi data type {fmi_data_type}"
@@ -204,17 +205,16 @@ def _cast_to_fmi_data_type(arg: Union[int, float, bool, str, Sequence],
         parsed_value: Union[int, float, bool]
         parsed_value = Parser().parse_type(arg) if isinstance(arg, str) else arg
         # cast to int / float / bool
-        if fmi_data_type == 'Integer':
+        if fmi_data_type == "Integer":
             return int(parsed_value)
-        elif fmi_data_type == 'Real':
+        elif fmi_data_type == "Real":
             return float(parsed_value)
         else:
             return bool(parsed_value)
-    elif fmi_data_type == 'String':
+    elif fmi_data_type == "String":
         # format as string
-        return Formatter().format_dict(arg) if isinstance(arg, Sequence
-                                                          ) else Formatter().format_type(arg)
-    elif fmi_data_type == 'Enumeration':
+        return Formatter().format_dict(arg) if isinstance(arg, Sequence) else Formatter().format_type(arg)
+    elif fmi_data_type == "Enumeration":
         # cast to list
         return list(arg) if isinstance(arg, Sequence) else [arg]
     else:
